@@ -1,7 +1,7 @@
 from flask import Response
 from datetime import date
-from . import bp
-from .. import messenger
+from polzybackend.announce import bp
+from polzybackend import messenger
 
 @bp.route('/listen', methods=['GET'])
 def listen():
@@ -13,10 +13,10 @@ def listen():
             yield msg
 
     return Response(
-    	stream(),
-    	headers={
-    		"Access-Control-Allow-Origin": "*",
-    		"Access-Control-Allow-Headers": "Origin, X-Requested-With, Content-Type, Accept",
-    	},
-    	mimetype='text/event-stream',
+        stream(),
+        headers={
+            "Access-Control-Allow-Origin": "*",
+            "Access-Control-Allow-Headers": "Origin, X-Requested-With, Content-Type, Accept",
+        },
+        mimetype='text/event-stream',
     )
\ No newline at end of file
