@@ -2,4 +2,4 @@ from flask import Blueprint
 
 bp = Blueprint('main', __name__)
 
-from . import routes
\ No newline at end of file
+from polzybackend.main import routes
\ No newline at end of file
